@@ -9,6 +9,8 @@ from onnx2tf.utils.common_functions import (
     convert_axis,
     print_node_info,
     inverted_operation_enable_disable,
+    make_tf_node_info,
+    process_neg_idx,
 )
 
 
@@ -71,7 +73,12 @@ def make_node(
     }
 
     # Generation of TF OP
-    # TODO: negative indices
+    indices_tensor = process_neg_idx(
+        data=input_tensor,
+        indices=indices_tensor,
+        batch_dims=batch_dims,
+    )
+
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.gather_nd(
             params=input_tensor,
@@ -79,3 +86,19 @@ def make_node(
             batch_dims=batch_dims,
             name=graph_node.name,
         )
+
+    # Generation of Debug Info
+    tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
+        make_tf_node_info(
+            node_info={
+                'tf_op_type': tf.gather_nd,
+                'tf_inputs': {
+                    'params': input_tensor,
+                    'indices': indices_tensor,
+                    'batch_dims': batch_dims,
+                },
+                'tf_outputs': {
+                    'output': tf_layers_dict[graph_node_output.name]['tf_node'],
+                },
+            }
+        )
