@@ -8,6 +8,7 @@ from onnx2tf.utils.common_functions import (
     get_constant_or_variable,
     print_node_info,
     inverted_operation_enable_disable,
+    make_tf_node_info,
 )
 
 
@@ -57,3 +58,18 @@ def make_node(
     multiplier = 0.16666666 # 0.16666667
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         input_tensor * tf.nn.relu6(input_tensor + 3) * multiplier
+
+    # Generation of Debug Info
+    tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
+        make_tf_node_info(
+            node_info={
+                'tf_op_type': 'HardSwish',
+                'tf_inputs': {
+                    'x': input_tensor,
+                    'multiplier': multiplier,
+                },
+                'tf_outputs': {
+                    'output': tf_layers_dict[graph_node_output.name]['tf_node'],
+                },
+            }
+        )
