@@ -8,6 +8,7 @@ from onnx2tf.utils.common_functions import (
     get_constant_or_variable,
     print_node_info,
     inverted_operation_enable_disable,
+    make_tf_node_info,
 )
 
 
@@ -57,11 +58,29 @@ def make_node(
     }
 
     # Generation of TF OP
+    input_tensor_1 = tf_layers_dict[graph_node_input_1.name]['tf_node'] \
+        if isinstance(graph_node_input_1, gs.Variable) else graph_node_input_1
+    input_tensor_2 = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
+        if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
+
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.math.subtract(
-            x=tf_layers_dict[graph_node_input_1.name]['tf_node'] \
-                if isinstance(graph_node_input_1, gs.Variable) else graph_node_input_1,
-            y=tf_layers_dict[graph_node_input_2.name]['tf_node'] \
-                if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2,
+            x=input_tensor_1,
+            y=input_tensor_2,
             name=graph_node.name,
         )
+
+    # Generation of Debug Info
+    tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
+        make_tf_node_info(
+            node_info={
+                'tf_op_type': tf.math.subtract,
+                'tf_inputs': {
+                    'x': input_tensor_1,
+                    'y': input_tensor_2,
+                },
+                'tf_outputs': {
+                    'output': tf_layers_dict[graph_node_output.name]['tf_node'],
+                },
+            }
+        )
