@@ -9,6 +9,7 @@ from onnx2tf.utils.common_functions import (
     convert_axis,
     print_node_info,
     inverted_operation_enable_disable,
+    make_tf_node_info,
 )
 
 
@@ -117,9 +118,25 @@ def make_node(
     }
 
     # Generation of TF OP
+    perm = list(perm) if perm is not None else None
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.transpose(
             a=input_tensor,
-            perm=list(perm) if perm is not None else None,
+            perm=perm,
             name=graph_node.name,
         )
+
+    # Generation of Debug Info
+    tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
+        make_tf_node_info(
+            node_info={
+                'tf_op_type': tf.transpose,
+                'tf_inputs': {
+                    'a': input_tensor,
+                    'perm': perm,
+                },
+                'tf_outputs': {
+                    'output': tf_layers_dict[graph_node_output.name]['tf_node'],
+                },
+            }
+        )
